#!/bin/sh

set -e

##functions.sh##

target="$1"
self="$2"
template="${self%.sh}"
flags="$3"

generated="$CCLUB_CONFIG_GENERATED_DIR/xen.cfg"

cp -p "$template" "$generated"
cp -p "${template}.md5sum" "${generated}.md5sum"

dom0_mem_bootarg=`grep '^GRUB_CMDLINE_XEN=.*[ "]dom0_mem=' "$target" |
                      head -n 1 |
                      sed -e 's/^.*[ "]\(dom0_mem=[^ "]\+\).*$/\1/'`
if [ -z "$dom0_mem_bootarg" ]; then
    # Try to get total memory from Xen, if it is running
    dom0_mem=`xl info 2>/dev/null | grep '^total_memory[: \t]' |
                  sed -e 's/^.*:[ \t]*\([0-9]\+\).*$/\1/'`

    if [ -z "$dom0_mem" ]; then
        dom0_mem=`grep '^MemTotal:[ \t]*.*kB' /proc/meminfo |
                      sed -e 's/.*:[ \t]*\([0-9]\+\).*$/\1/'`
        if [ -n "$dom0_mem" ]; then
            # Convert to the nearest MB
            dom0_mem=`expr \( "$dom0_mem" + 512 \) / 1024`
        fi
    fi

    # If we got some total amount of memory to work with, do some math to 
    # calculate how much to give to the Dom0.
    # But, use at least 1 GB and no more than 8 GB
    if [ -n "$dom0_mem" ]; then
        dom0_mem=`expr \( "$dom0_mem" / 8 + 128 \) / 256 \* 256`
        if [ "$dom0_mem" -lt 1024 ]; then
            dom0_mem=1024
        elif [ "$dom0_mem" -gt 8192 ]; then
            dom0_mem=8192
        fi
        dom0_mem_bootarg="dom0_mem=${dom0_mem}M,max:${dom0_mem}M"
    fi
fi

sed -i -e "s/##dom0_mem##/$dom0_mem_bootarg/" "$generated"


configure_via_copy "$target" "$generated" "$flags"
